# Django-On-Chain

A wrapper for python `requests` package customized to use in Cafe Bazaar projects.

## Installation

```bash
pip install django-on-chain

# or:

pip install -e git+ssh://git@git.cafebazaar.ir/Pishkhan/django-on-chain.git@master#egg=django-on-chain
```

## TODO

Add documentation.
